# Security Policy

## Supported Versions

Keeping **CLIbrary** up to date is the best way to protect yourself against security vulnerabilities, so please make sure you're using the latest version.  
Every reported vulnerability will be solved and an update will be issued.

## Reporting a Vulnerability

Vulnerabilities should be reported either via a private report.  
Be sure to include the version of the software, the steps to reproduce the vulnerability, and any information you have about the potential impact of the vulnerability.
